import { NativeModules, Platform } from 'react-native';
const funsdk = NativeModules.FunSDKDevAlarmModule;

// Android

// iOS

// Android
/**
 * Searches alarm messages based on the provided parameters.
 *
 * @param {SearchAlarmMsgParams} params - The parameters for searching alarm messages.
 * @return {Promise<AlarmInfo[]>} A promise that resolves to an array of alarm information.
 */
export function searchAlarmMsg(params) {
  if (Platform.OS === 'android') {
    return funsdk.searchAlarmMsg({
      ...params,
      searchDays: 1
    });
  } else {
    throw new Error('searchAlarmMsgByTime for Android only');
  }
}

// iOS
export function searchAlarmMsgByTime(params) {
  if (Platform.OS === 'ios') {
    return funsdk.searchAlarmMsgByTime(params);
  } else {
    throw new Error('searchAlarmMsgByTime for iOS only');
  }
}
/**
 * Deletes alarm information.
 *
 * @param {DeleteAlarmInfoParams} params - The parameters for deleting alarm information.
 * @param {string} params.deviceId - The ID of the device.
 * @param {'MSG' | 'VIDEO'} params.deleteType - The type of deletion ('MSG' or 'VIDEO').
 * @param {Array<{id: string}>} params.alarmInfos - The array of alarm information IDs to delete.
 * @throws {Error} Throws an error if the length of alarmInfos is more than 60.
 * @return {Promise<DeleteAlarmInfoResponse>} A promise that resolves to the response containing the success status and the deleted alarm information.
 */
export function deleteAlarmInfo(params) {
  if (params.alarmInfos.length > 60) {
    throw new Error("alarmInfos length can't be more than 60");
  }
  if (Platform.OS !== 'android') {
    var _params$alarmInfos, _params$alarmInfos$;
    if (params.alarmInfos.length > 1) {
      throw new Error('delete only 1 item in iOS');
    }
    // throw new Error('deleteAlarmInfo for Android only');
    return funsdk.deleteOneAlarmInfo({
      deviceId: params.deviceId,
      deleteType: params.deleteType,
      alarmID: (_params$alarmInfos = params.alarmInfos) === null || _params$alarmInfos === void 0 ? void 0 : (_params$alarmInfos$ = _params$alarmInfos[0]) === null || _params$alarmInfos$ === void 0 ? void 0 : _params$alarmInfos$.id
    });
  }
  return funsdk.deleteAlarmInfo(params);
}
export function deleteOneAlarmInfo(params) {
  if (Platform.OS !== 'ios') {
    throw new Error('deleteOneAlarmInfo for iOS only');
  }
  return funsdk.deleteOneAlarmInfo(params);
}

/**
 * Deletes all alarm messages based on the provided parameters, excluding the alarmInfos field.
 *
 * @param {Omit<DeleteAlarmInfoParams, 'alarmInfos'>} params - The parameters for deleting alarm information, excluding the alarmInfos field.
 * @return {Promise<Omit<DeleteAlarmInfoResponse, 'alarmInfos'>>} A promise that resolves to the response containing the success status and the deleted alarm information, excluding the alarmInfos field.
 */
export function deleteAllAlarmMsg(params) {
  return funsdk.deleteAllAlarmMsg(params);
}
export function linkAlarm(params) {
  return funsdk.linkAlarm(params);
}
export function unlinkAlarm(params) {
  return funsdk.unlinkAlarm(params);
}
export let EMSGLANGUAGE = /*#__PURE__*/function (EMSGLANGUAGE) {
  EMSGLANGUAGE[EMSGLANGUAGE["ELG_AUTO"] = 0] = "ELG_AUTO";
  EMSGLANGUAGE[EMSGLANGUAGE["ELG_ENGLISH"] = 1] = "ELG_ENGLISH";
  EMSGLANGUAGE[EMSGLANGUAGE["ELG_CHINESE"] = 2] = "ELG_CHINESE";
  EMSGLANGUAGE[EMSGLANGUAGE["ELG_JAPANESE"] = 3] = "ELG_JAPANESE";
  return EMSGLANGUAGE;
}({});
export let ALARM_PUSH_TYPE = /*#__PURE__*/function (ALARM_PUSH_TYPE) {
  ALARM_PUSH_TYPE[ALARM_PUSH_TYPE["DevelopmentType"] = 200] = "DevelopmentType";
  ALARM_PUSH_TYPE[ALARM_PUSH_TYPE["ProductionType"] = 3] = "ProductionType";
  return ALARM_PUSH_TYPE;
}({});
export function initAlarmServer(params) {
  return funsdk.initAlarmServer({
    language: EMSGLANGUAGE.ELG_ENGLISH,
    pushType: ALARM_PUSH_TYPE.DevelopmentType,
    ...params
  });
}
export function getAlarmState(params) {
  return funsdk.getAlarmState(params);
}
export function setAlarmState(params) {
  return funsdk.setAlarmState(params);
}
//# sourceMappingURL=index.js.map