import type { AlarmType } from '../types/alarm';
import type { DeviceManagerPromiseSuccessType } from '../../src/device';
export type SearchAlarmMsgParams = {
    deviceId: string;
    deviceChannel: number;
    alarmType: number;
    searchTime: number;
    searchDays: number;
    imgSizes: {
        imgHeight: number;
        imgWidth: number;
    };
};
export type SearchAlarmMsgByTimeParams = {
    deviceId: string;
    deviceChannel: number;
    alarmType: number;
    startTime: number;
    endTime: number;
};
export type AlarmInfo = {
    ID: string;
    picSize: number;
    AlarmInfo: {
        Status: string | null;
        StartTime: string | null;
        MsgStatus: string;
        Channel: string;
        Event: AlarmType;
        DevName: string;
        Pic: string;
    };
    alarmRing: string | null;
    channel: number;
    devName: string | null;
    event: AlarmType | null;
    extInfo: string | null;
    id: string;
    isHavePic: boolean;
    linkCenter: {
        msgType: string | null;
        msg: string | null;
        subSn: string | null;
        modelType: number | null;
    } | null;
    pic: string | null;
    picError: number;
    picsize: number;
    pushMsg: string | null;
    serialNumber: string | null;
    startTime: string | null;
    status: string | null;
    videoInfo: boolean;
};
/**
 * Searches alarm messages based on the provided parameters.
 *
 * @param {SearchAlarmMsgParams} params - The parameters for searching alarm messages.
 * @return {Promise<AlarmInfo[]>} A promise that resolves to an array of alarm information.
 */
export declare function searchAlarmMsg(params: SearchAlarmMsgParams): Promise<AlarmInfo[]>;
export declare function searchAlarmMsgByTime(params: SearchAlarmMsgByTimeParams): Promise<AlarmInfo[]>;
export type DeleteAlarmInfoParams = {
    deviceId: string;
    deleteType: 'MSG' | 'VIDEO';
    alarmInfos: {
        id: string;
    }[];
};
export type DeleteOneAlarmInfoParams = {
    deviceId: string;
    deleteType: 'MSG' | 'VIDEO';
    alarmID: string;
};
export type DeleteAlarmInfoResponse = {
    isSuccess: boolean;
    alarmInfos: AlarmInfo[];
};
/**
 * Deletes alarm information.
 *
 * @param {DeleteAlarmInfoParams} params - The parameters for deleting alarm information.
 * @param {string} params.deviceId - The ID of the device.
 * @param {'MSG' | 'VIDEO'} params.deleteType - The type of deletion ('MSG' or 'VIDEO').
 * @param {Array<{id: string}>} params.alarmInfos - The array of alarm information IDs to delete.
 * @throws {Error} Throws an error if the length of alarmInfos is more than 60.
 * @return {Promise<DeleteAlarmInfoResponse>} A promise that resolves to the response containing the success status and the deleted alarm information.
 */
export declare function deleteAlarmInfo(params: DeleteAlarmInfoParams): Promise<DeleteAlarmInfoResponse>;
export declare function deleteOneAlarmInfo(params: DeleteOneAlarmInfoParams): Promise<DeleteAlarmInfoResponse>;
/**
 * Deletes all alarm messages based on the provided parameters, excluding the alarmInfos field.
 *
 * @param {Omit<DeleteAlarmInfoParams, 'alarmInfos'>} params - The parameters for deleting alarm information, excluding the alarmInfos field.
 * @return {Promise<Omit<DeleteAlarmInfoResponse, 'alarmInfos'>>} A promise that resolves to the response containing the success status and the deleted alarm information, excluding the alarmInfos field.
 */
export declare function deleteAllAlarmMsg(params: Omit<DeleteAlarmInfoParams, 'alarmInfos'>): Promise<Omit<DeleteAlarmInfoResponse, 'alarmInfos'>>;
export type LinkAlarmParams = {
    deviceId: string;
    deviceLogin: string;
    devicePassword: string;
    deviceName?: string;
};
export declare function linkAlarm(params: LinkAlarmParams): Promise<any>;
export type UnlinkAlarmParams = {
    deviceId: string;
};
export declare function unlinkAlarm(params: UnlinkAlarmParams): Promise<any>;
export declare enum EMSGLANGUAGE {
    ELG_AUTO = 0,
    ELG_ENGLISH = 1,
    ELG_CHINESE = 2,
    ELG_JAPANESE = 3
}
export declare enum ALARM_PUSH_TYPE {
    DevelopmentType = 200,
    ProductionType = 3
}
export type InitAlarmServerParams = {
    username: string;
    password: string;
    token: string;
    language?: EMSGLANGUAGE;
    pushType?: ALARM_PUSH_TYPE;
    pushThirdServerURL?: string;
};
export declare function initAlarmServer(params: InitAlarmServerParams): Promise<any>;
export type GetAlarmStateParams = {
    deviceId: string;
};
export type GetAlarmStateResult = DeviceManagerPromiseSuccessType & {
    value: {
        'Name': 'NetWork.PMS';
        'NetWork.PMS': {
            BoxID: string;
            Enable: boolean;
            Port: number;
            PushInterval: number;
            ServName: string;
        };
        'Ret': number;
        'SessionID': string;
    };
};
export declare function getAlarmState(params: GetAlarmStateParams): Promise<GetAlarmStateResult>;
export type SetAlarmStateParams = {
    deviceId: string;
    isAlertEnabled: boolean;
};
export type SetAlarmStateResult = DeviceManagerPromiseSuccessType & {
    value: {
        Name: 'NetWork.PMS';
        Ret: number;
        SessionID: string;
    };
};
export declare function setAlarmState(params: SetAlarmStateParams): Promise<SetAlarmStateResult>;
//# sourceMappingURL=index.d.ts.map